import typing
from datetime import datetime

import attr

from strategy_bridge.bus import data_bus, Record


@attr.s(auto_attribs=True)
class DataWriter:

    write_topic_name: str
    max_persisted_records_count: int

    def __attrs_post_init__(self):
        data_bus.register_topic(self.write_topic_name, self.max_persisted_records_count)

    def write(self, content: typing.Any):
        record = Record(content, datetime.now().timestamp())
        data_bus.write(self.write_topic_name, record)



import asyncio
import logging
import typing

import attr

from abc import ABC, abstractmethod


logger = logging.getLogger(__name__)


@attr.s(auto_attribs=True, kw_only=True)
class BaseProcessor(ABC):

    processing_pause: typing.Optional[int] = 1

    async def run(self) -> None:
        logger.info(f"Running processor: {self.__class__.__name__}")
        while True:
            await self.process()
            if self.processing_pause:
                await asyncio.sleep(self.processing_pause)

    @abstractmethod
    async def process(self) -> None:
        pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grsim_commands.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grsim_commands.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14grsim_commands.proto\"\xea\x01\n\x13grSim_Robot_Command\x12\n\n\x02id\x18\x01 \x02(\r\x12\x12\n\nkickspeedx\x18\x02 \x02(\x02\x12\x12\n\nkickspeedz\x18\x03 \x02(\x02\x12\x12\n\nveltangent\x18\x04 \x02(\x02\x12\x11\n\tvelnormal\x18\x05 \x02(\x02\x12\x12\n\nvelangular\x18\x06 \x02(\x02\x12\x0f\n\x07spinner\x18\x07 \x02(\x08\x12\x13\n\x0bwheelsspeed\x18\x08 \x02(\x08\x12\x0e\n\x06wheel1\x18\t \x01(\x02\x12\x0e\n\x06wheel2\x18\n \x01(\x02\x12\x0e\n\x06wheel3\x18\x0b \x01(\x02\x12\x0e\n\x06wheel4\x18\x0c \x01(\x02\"g\n\x0egrSim_Commands\x12\x11\n\ttimestamp\x18\x01 \x02(\x01\x12\x14\n\x0cisteamyellow\x18\x02 \x02(\x08\x12,\n\x0erobot_commands\x18\x03 \x03(\x0b\x32\x14.grSim_Robot_Command'
)




_GRSIM_ROBOT_COMMAND = _descriptor.Descriptor(
  name='grSim_Robot_Command',
  full_name='grSim_Robot_Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grSim_Robot_Command.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kickspeedx', full_name='grSim_Robot_Command.kickspeedx', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kickspeedz', full_name='grSim_Robot_Command.kickspeedz', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='veltangent', full_name='grSim_Robot_Command.veltangent', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velnormal', full_name='grSim_Robot_Command.velnormal', index=4,
      number=5, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velangular', full_name='grSim_Robot_Command.velangular', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spinner', full_name='grSim_Robot_Command.spinner', index=6,
      number=7, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheelsspeed', full_name='grSim_Robot_Command.wheelsspeed', index=7,
      number=8, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel1', full_name='grSim_Robot_Command.wheel1', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel2', full_name='grSim_Robot_Command.wheel2', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel3', full_name='grSim_Robot_Command.wheel3', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wheel4', full_name='grSim_Robot_Command.wheel4', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=259,
)


_GRSIM_COMMANDS = _descriptor.Descriptor(
  name='grSim_Commands',
  full_name='grSim_Commands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='grSim_Commands.timestamp', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isteamyellow', full_name='grSim_Commands.isteamyellow', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robot_commands', full_name='grSim_Commands.robot_commands', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=364,
)

_GRSIM_COMMANDS.fields_by_name['robot_commands'].message_type = _GRSIM_ROBOT_COMMAND
DESCRIPTOR.message_types_by_name['grSim_Robot_Command'] = _GRSIM_ROBOT_COMMAND
DESCRIPTOR.message_types_by_name['grSim_Commands'] = _GRSIM_COMMANDS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

grSim_Robot_Command = _reflection.GeneratedProtocolMessageType('grSim_Robot_Command', (_message.Message,), {
  'DESCRIPTOR' : _GRSIM_ROBOT_COMMAND,
  '__module__' : 'grsim_commands_pb2'
  # @@protoc_insertion_point(class_scope:grSim_Robot_Command)
  })
_sym_db.RegisterMessage(grSim_Robot_Command)

grSim_Commands = _reflection.GeneratedProtocolMessageType('grSim_Commands', (_message.Message,), {
  'DESCRIPTOR' : _GRSIM_COMMANDS,
  '__module__' : 'grsim_commands_pb2'
  # @@protoc_insertion_point(class_scope:grSim_Commands)
  })
_sym_db.RegisterMessage(grSim_Commands)


# @@protoc_insertion_point(module_scope)



import attr

from strategy_bridge.bus import DataWriter
from strategy_bridge.common import config
from strategy_bridge.processors import BaseProcessor
from strategy_bridge.pb.messages_robocup_ssl_wrapper_pb2 import SSL_WrapperPacket
from strategy_bridge.larcmacs.receiver import ZmqReceiver


@attr.s(auto_attribs=True)
class VisionDetectionsCollector(BaseProcessor):

    max_records_to_persist: int = 30
    records_writer: DataWriter = attr.ib(init=False)
    receiver: ZmqReceiver = attr.ib(init=False)

    def __attrs_post_init__(self) -> None:
        self.records_writer = DataWriter(config.VISION_DETECTIONS_TOPIC, self.max_records_to_persist)
        self.receiver = ZmqReceiver(port=config.VISION_DETECTIONS_SUBSCRIBE_PORT)
        self._ssl_converter = SSL_WrapperPacket()

    async def process(self):
        message = self.receiver.next_message()
        if not message:
            return
        package = self._ssl_converter.FromString(message)
        self.records_writer.write(package)



import json

import attr

from strategy_bridge.bus import DataWriter
from strategy_bridge.common import config
from strategy_bridge.model.referee import RefereeCommand
from strategy_bridge.processors import BaseProcessor
from strategy_bridge.larcmacs.receiver import ZmqReceiver


@attr.s(auto_attribs=True)
class RefereeCommandsCollector(BaseProcessor):

    max_records_to_persist: int = 30
    records_writer: DataWriter = attr.ib(init=False)
    receiver: ZmqReceiver = attr.ib(init=False)

    def __attrs_post_init__(self) -> None:
        self.records_writer = DataWriter(config.REFEREE_COMMANDS_TOPIC, self.max_records_to_persist)
        self.receiver = ZmqReceiver(port=config.REFEREE_COMMANDS_SUBSCRIBE_PORT)

    async def process(self):
        message = self.receiver.next_message()
        if not message:
            return
        parsed_message = json.loads(bytes(message))
        command = RefereeCommand(
            state=parsed_message['state'],
            commandForTeam=parsed_message['team'],
            isPartOfFieldLeft=parsed_message['is_left'],
        )
        self.records_writer.write(command)



from strategy_bridge.bus import data_bus
from strategy_bridge.common import config
from strategy_bridge.processors import VisionDetectionsCollector, RobotCommandsSender
from strategy_bridge.processors.matlab_controller import MatlabController
from strategy_bridge.processors.referee_commands_collector import RefereeCommandsCollector
from strategy_bridge.runner import Runner


config.init_logging()


processors = [
    VisionDetectionsCollector(),
    RefereeCommandsCollector(),
    MatlabController(),
    RobotCommandsSender()
]

runner = Runner(processors=processors)
runner.run()


ssl_packages = data_bus.read_all(config.VISION_DETECTIONS_TOPIC)
referee_commands = data_bus.read_all(config.REFEREE_COMMANDS_TOPIC)
control = data_bus.read_all(config.ROBOT_COMMANDS_TOPIC)



import typing
from enum import Enum

import attr


class Team(Enum):
    BLUE = 1
    YELLOW = 2


@attr.s(auto_attribs=True)
class FrameInfo:
    frame_number: int
    # TODO: Convert to datetime
    t_capture: float
    t_sent: float
    camera_id: int


@attr.s(auto_attribs=True)
class RobotDetection:
    frame_info: FrameInfo
    team: Team
    confidence: float
    robot_id: int
    x: float
    y: float
    orientation: float
    # TODO: Are these additional coordinates needed?
    pixel_x: float
    pixel_y: float


@attr.s(auto_attribs=True)
class BallDetection:
    frame_info: FrameInfo
    confidence: float
    x: float
    y: float
    z: float
    # TODO: Are these additional coordinates needed?
    pixel_x: float
    pixel_y: float


@attr.s(auto_attribs=True)
class Geometry:
    # TODO: Implement
    pass


@attr.s(auto_attribs=True)
class Detection:
    balls: typing.List[BallDetection]
    robots: typing.List[RobotDetection]
    geometry: typing.Optional[Geometry]

    def get_robot(self, team: Team, robot_id: int) -> typing.Optional[RobotDetection]:
        robot = [r for r in self.robots if r.team.value == team.value and r.robot_id == robot_id]
        return robot[0] if robot else None

    def get_ball(self) -> typing.Optional[BallDetection]:
        return self.balls[0] if self.balls else None




import asyncio
import os
import typing

import attr
import matlab
import matlab.engine
import numpy as np
from matlab.engine import FutureResult

from strategy_bridge.common import config


@attr.s(auto_attribs=True)
class MatlabEngine:

    engine: typing.Any = attr.ib(init=False)

    def __attrs_post_init__(self):
        self.engine = matlab.engine.start_matlab()
        matlab_main_dir = config.MATLAB_SCRIPTS_PATH
        self.engine.addpath(matlab_main_dir)
        for path in os.listdir(matlab_main_dir):
            path = os.path.join(matlab_main_dir, path)
            if os.path.isdir(path):
                self.engine.addpath(os.path.join(matlab_main_dir, path), nargout=0)

    async def run_function(self, function_name: str, *args) -> typing.Optional[np.ndarray]:
        converted_args = [matlab.double(arg) for arg in args]
        engine_function = getattr(self.engine, function_name)
        future_result = engine_function(*converted_args, background=True)
        return await self.wait_for_result(future_result)
        # if future_result:
        #
        # else:
        #     return None

    async def wait_for_result(self, future: FutureResult) -> np.ndarray:
        while not future.done():
            await asyncio.sleep(1)
        return np.array(future.result())



matlab_engine = MatlabEngine()



import attr
import numpy as np

from strategy_bridge.bus import DataReader, DataWriter
from strategy_bridge.common import config
from strategy_bridge.model.referee import RefereeCommand
from strategy_bridge.processors import BaseProcessor


@attr.s(auto_attribs=True)
class PythonControllerTemplate(BaseProcessor):

    max_commands_to_persist: int = 20

    vision_reader: DataReader = attr.ib(init=False, default=DataReader(config.VISION_DETECTIONS_TOPIC))
    referee_reader: DataReader = attr.ib(init=False, default=DataReader(config.REFEREE_COMMANDS_TOPIC))
    commands_writer: DataWriter = attr.ib(init=False)

    CAMERAS_COUNT: int = 4
    MAX_BALLS_IN_CAMERA: int = 64
    MAX_BALLS_IN_FIELD: int = CAMERAS_COUNT * MAX_BALLS_IN_CAMERA
    BALL_PACKET_SIZE: int = 3

    ROBOTS_MAX_COUNT: int = 32
    TEAM_ROBOTS_MAX_COUNT: int = ROBOTS_MAX_COUNT // 2
    SINGLE_ROBOT_PACKET_SIZE = 5
    ROBOT_TEAM_PACKET_SIZE: int = SINGLE_ROBOT_PACKET_SIZE * TEAM_ROBOTS_MAX_COUNT

    GEOMETRY_PACKET_SIZE: int = 2

    def __attrs_post_init__(self):
        self.commands_writer = DataWriter(config.ROBOT_COMMANDS_TOPIC, self.max_commands_to_persist)

    def get_last_referee_command(self) -> RefereeCommand:
        referee_commands = self.referee_reader.read_new()
        if referee_commands:
            return referee_commands[-1]
        return RefereeCommand(0, 0, False)

    async def process(self) -> None:
        balls = np.zeros(self.BALL_PACKET_SIZE * self.MAX_BALLS_IN_FIELD)
        robots_blue = np.zeros(self.ROBOT_TEAM_PACKET_SIZE)
        robots_yellow = np.zeros(self.ROBOT_TEAM_PACKET_SIZE)
        field_info = np.zeros(self.GEOMETRY_PACKET_SIZE)

        for ssl_package in self.vision_reader.read_new():
            geometry = ssl_package.geometry
            if geometry:
                field_info[0] = geometry.field.field_length
                field_info[1] = geometry.field.field_width

            detection = ssl_package.detection
            if not detection:
                continue

            camera_id = detection.camera_id
            for ball_ind, ball in enumerate(detection.balls):
                balls[ball_ind + (camera_id - 1) * self.MAX_BALLS_IN_CAMERA] = camera_id
                balls[ball_ind + self.MAX_BALLS_IN_FIELD + (camera_id - 1) * self.MAX_BALLS_IN_CAMERA] = ball.x
                balls[ball_ind + 2 * self.MAX_BALLS_IN_FIELD + (camera_id - 1) * self.MAX_BALLS_IN_CAMERA] = ball.y

            # TODO: Barrier states
            for robot in detection.robots_blue:
                robots_blue[robot.robot_id] = camera_id
                robots_blue[robot.robot_id + self.TEAM_ROBOTS_MAX_COUNT] = robot.x
                robots_blue[robot.robot_id + self.TEAM_ROBOTS_MAX_COUNT * 2] = robot.y
                robots_blue[robot.robot_id + self.TEAM_ROBOTS_MAX_COUNT * 3] = robot.orientation

            for robot in detection.robots_yellow:
                robots_yellow[robot.robot_id] = camera_id
                robots_yellow[robot.robot_id + self.TEAM_ROBOTS_MAX_COUNT] = robot.x
                robots_yellow[robot.robot_id + self.TEAM_ROBOTS_MAX_COUNT * 2] = robot.y
                robots_yellow[robot.robot_id + self.TEAM_ROBOTS_MAX_COUNT * 3] = robot.orientation

            referee_command = self.get_last_referee_command()
            rules = [5.0]*32*13

            import struct
            b = bytes()
            rules = b.join((struct.pack('d', rule) for rule in rules))
            self.commands_writer.write(rules)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages_robocup_ssl_geometry.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages_robocup_ssl_geometry.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#messages_robocup_ssl_geometry.proto\" \n\x08Vector2f\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\"e\n\x14SSL_FieldLineSegment\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x15\n\x02p1\x18\x02 \x02(\x0b\x32\t.Vector2f\x12\x15\n\x02p2\x18\x03 \x02(\x0b\x32\t.Vector2f\x12\x11\n\tthickness\x18\x04 \x02(\x02\"y\n\x13SSL_FieldCicularArc\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x19\n\x06\x63\x65nter\x18\x02 \x02(\x0b\x32\t.Vector2f\x12\x0e\n\x06radius\x18\x03 \x02(\x02\x12\n\n\x02\x61\x31\x18\x04 \x02(\x02\x12\n\n\x02\x61\x32\x18\x05 \x02(\x02\x12\x11\n\tthickness\x18\x06 \x02(\x02\"\xd8\x01\n\x15SSL_GeometryFieldSize\x12\x14\n\x0c\x66ield_length\x18\x01 \x02(\x05\x12\x13\n\x0b\x66ield_width\x18\x02 \x02(\x05\x12\x12\n\ngoal_width\x18\x03 \x02(\x05\x12\x12\n\ngoal_depth\x18\x04 \x02(\x05\x12\x16\n\x0e\x62oundary_width\x18\x05 \x02(\x05\x12*\n\x0b\x66ield_lines\x18\x06 \x03(\x0b\x32\x15.SSL_FieldLineSegment\x12(\n\nfield_arcs\x18\x07 \x03(\x0b\x32\x14.SSL_FieldCicularArc\"\xc9\x02\n\x1dSSL_GeometryCameraCalibration\x12\x11\n\tcamera_id\x18\x01 \x02(\r\x12\x14\n\x0c\x66ocal_length\x18\x02 \x02(\x02\x12\x19\n\x11principal_point_x\x18\x03 \x02(\x02\x12\x19\n\x11principal_point_y\x18\x04 \x02(\x02\x12\x12\n\ndistortion\x18\x05 \x02(\x02\x12\n\n\x02q0\x18\x06 \x02(\x02\x12\n\n\x02q1\x18\x07 \x02(\x02\x12\n\n\x02q2\x18\x08 \x02(\x02\x12\n\n\x02q3\x18\t \x02(\x02\x12\n\n\x02tx\x18\n \x02(\x02\x12\n\n\x02ty\x18\x0b \x02(\x02\x12\n\n\x02tz\x18\x0c \x02(\x02\x12\x1f\n\x17\x64\x65rived_camera_world_tx\x18\r \x01(\x02\x12\x1f\n\x17\x64\x65rived_camera_world_ty\x18\x0e \x01(\x02\x12\x1f\n\x17\x64\x65rived_camera_world_tz\x18\x0f \x01(\x02\"h\n\x10SSL_GeometryData\x12%\n\x05\x66ield\x18\x01 \x02(\x0b\x32\x16.SSL_GeometryFieldSize\x12-\n\x05\x63\x61lib\x18\x02 \x03(\x0b\x32\x1e.SSL_GeometryCameraCalibration'
)




_VECTOR2F = _descriptor.Descriptor(
  name='Vector2f',
  full_name='Vector2f',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='Vector2f.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='Vector2f.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=71,
)


_SSL_FIELDLINESEGMENT = _descriptor.Descriptor(
  name='SSL_FieldLineSegment',
  full_name='SSL_FieldLineSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='SSL_FieldLineSegment.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p1', full_name='SSL_FieldLineSegment.p1', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p2', full_name='SSL_FieldLineSegment.p2', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thickness', full_name='SSL_FieldLineSegment.thickness', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=174,
)


_SSL_FIELDCICULARARC = _descriptor.Descriptor(
  name='SSL_FieldCicularArc',
  full_name='SSL_FieldCicularArc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='SSL_FieldCicularArc.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center', full_name='SSL_FieldCicularArc.center', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='SSL_FieldCicularArc.radius', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a1', full_name='SSL_FieldCicularArc.a1', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a2', full_name='SSL_FieldCicularArc.a2', index=4,
      number=5, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thickness', full_name='SSL_FieldCicularArc.thickness', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=297,
)


_SSL_GEOMETRYFIELDSIZE = _descriptor.Descriptor(
  name='SSL_GeometryFieldSize',
  full_name='SSL_GeometryFieldSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_length', full_name='SSL_GeometryFieldSize.field_length', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_width', full_name='SSL_GeometryFieldSize.field_width', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_width', full_name='SSL_GeometryFieldSize.goal_width', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_depth', full_name='SSL_GeometryFieldSize.goal_depth', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary_width', full_name='SSL_GeometryFieldSize.boundary_width', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_lines', full_name='SSL_GeometryFieldSize.field_lines', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_arcs', full_name='SSL_GeometryFieldSize.field_arcs', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=516,
)


_SSL_GEOMETRYCAMERACALIBRATION = _descriptor.Descriptor(
  name='SSL_GeometryCameraCalibration',
  full_name='SSL_GeometryCameraCalibration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_id', full_name='SSL_GeometryCameraCalibration.camera_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='focal_length', full_name='SSL_GeometryCameraCalibration.focal_length', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='principal_point_x', full_name='SSL_GeometryCameraCalibration.principal_point_x', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='principal_point_y', full_name='SSL_GeometryCameraCalibration.principal_point_y', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distortion', full_name='SSL_GeometryCameraCalibration.distortion', index=4,
      number=5, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q0', full_name='SSL_GeometryCameraCalibration.q0', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q1', full_name='SSL_GeometryCameraCalibration.q1', index=6,
      number=7, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q2', full_name='SSL_GeometryCameraCalibration.q2', index=7,
      number=8, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q3', full_name='SSL_GeometryCameraCalibration.q3', index=8,
      number=9, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx', full_name='SSL_GeometryCameraCalibration.tx', index=9,
      number=10, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ty', full_name='SSL_GeometryCameraCalibration.ty', index=10,
      number=11, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tz', full_name='SSL_GeometryCameraCalibration.tz', index=11,
      number=12, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derived_camera_world_tx', full_name='SSL_GeometryCameraCalibration.derived_camera_world_tx', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derived_camera_world_ty', full_name='SSL_GeometryCameraCalibration.derived_camera_world_ty', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derived_camera_world_tz', full_name='SSL_GeometryCameraCalibration.derived_camera_world_tz', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=848,
)


_SSL_GEOMETRYDATA = _descriptor.Descriptor(
  name='SSL_GeometryData',
  full_name='SSL_GeometryData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='SSL_GeometryData.field', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calib', full_name='SSL_GeometryData.calib', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=850,
  serialized_end=954,
)

_SSL_FIELDLINESEGMENT.fields_by_name['p1'].message_type = _VECTOR2F
_SSL_FIELDLINESEGMENT.fields_by_name['p2'].message_type = _VECTOR2F
_SSL_FIELDCICULARARC.fields_by_name['center'].message_type = _VECTOR2F
_SSL_GEOMETRYFIELDSIZE.fields_by_name['field_lines'].message_type = _SSL_FIELDLINESEGMENT
_SSL_GEOMETRYFIELDSIZE.fields_by_name['field_arcs'].message_type = _SSL_FIELDCICULARARC
_SSL_GEOMETRYDATA.fields_by_name['field'].message_type = _SSL_GEOMETRYFIELDSIZE
_SSL_GEOMETRYDATA.fields_by_name['calib'].message_type = _SSL_GEOMETRYCAMERACALIBRATION
DESCRIPTOR.message_types_by_name['Vector2f'] = _VECTOR2F
DESCRIPTOR.message_types_by_name['SSL_FieldLineSegment'] = _SSL_FIELDLINESEGMENT
DESCRIPTOR.message_types_by_name['SSL_FieldCicularArc'] = _SSL_FIELDCICULARARC
DESCRIPTOR.message_types_by_name['SSL_GeometryFieldSize'] = _SSL_GEOMETRYFIELDSIZE
DESCRIPTOR.message_types_by_name['SSL_GeometryCameraCalibration'] = _SSL_GEOMETRYCAMERACALIBRATION
DESCRIPTOR.message_types_by_name['SSL_GeometryData'] = _SSL_GEOMETRYDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Vector2f = _reflection.GeneratedProtocolMessageType('Vector2f', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR2F,
  '__module__' : 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:Vector2f)
  })
_sym_db.RegisterMessage(Vector2f)

SSL_FieldLineSegment = _reflection.GeneratedProtocolMessageType('SSL_FieldLineSegment', (_message.Message,), {
  'DESCRIPTOR' : _SSL_FIELDLINESEGMENT,
  '__module__' : 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_FieldLineSegment)
  })
_sym_db.RegisterMessage(SSL_FieldLineSegment)

SSL_FieldCicularArc = _reflection.GeneratedProtocolMessageType('SSL_FieldCicularArc', (_message.Message,), {
  'DESCRIPTOR' : _SSL_FIELDCICULARARC,
  '__module__' : 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_FieldCicularArc)
  })
_sym_db.RegisterMessage(SSL_FieldCicularArc)

SSL_GeometryFieldSize = _reflection.GeneratedProtocolMessageType('SSL_GeometryFieldSize', (_message.Message,), {
  'DESCRIPTOR' : _SSL_GEOMETRYFIELDSIZE,
  '__module__' : 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_GeometryFieldSize)
  })
_sym_db.RegisterMessage(SSL_GeometryFieldSize)

SSL_GeometryCameraCalibration = _reflection.GeneratedProtocolMessageType('SSL_GeometryCameraCalibration', (_message.Message,), {
  'DESCRIPTOR' : _SSL_GEOMETRYCAMERACALIBRATION,
  '__module__' : 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_GeometryCameraCalibration)
  })
_sym_db.RegisterMessage(SSL_GeometryCameraCalibration)

SSL_GeometryData = _reflection.GeneratedProtocolMessageType('SSL_GeometryData', (_message.Message,), {
  'DESCRIPTOR' : _SSL_GEOMETRYDATA,
  '__module__' : 'messages_robocup_ssl_geometry_pb2'
  # @@protoc_insertion_point(class_scope:SSL_GeometryData)
  })
_sym_db.RegisterMessage(SSL_GeometryData)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grsim_packet.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import grsim_commands_pb2 as grsim__commands__pb2
import grsim_replacement_pb2 as grsim__replacement__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grsim_packet.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12grsim_packet.proto\x1a\x14grsim_commands.proto\x1a\x17grsim_replacement.proto\"Z\n\x0cgrSim_Packet\x12!\n\x08\x63ommands\x18\x01 \x01(\x0b\x32\x0f.grSim_Commands\x12\'\n\x0breplacement\x18\x02 \x01(\x0b\x32\x12.grSim_Replacement'
  ,
  dependencies=[grsim__commands__pb2.DESCRIPTOR,grsim__replacement__pb2.DESCRIPTOR,])




_GRSIM_PACKET = _descriptor.Descriptor(
  name='grSim_Packet',
  full_name='grSim_Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commands', full_name='grSim_Packet.commands', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replacement', full_name='grSim_Packet.replacement', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=159,
)

_GRSIM_PACKET.fields_by_name['commands'].message_type = grsim__commands__pb2._GRSIM_COMMANDS
_GRSIM_PACKET.fields_by_name['replacement'].message_type = grsim__replacement__pb2._GRSIM_REPLACEMENT
DESCRIPTOR.message_types_by_name['grSim_Packet'] = _GRSIM_PACKET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

grSim_Packet = _reflection.GeneratedProtocolMessageType('grSim_Packet', (_message.Message,), {
  'DESCRIPTOR' : _GRSIM_PACKET,
  '__module__' : 'grsim_packet_pb2'
  # @@protoc_insertion_point(class_scope:grSim_Packet)
  })
_sym_db.RegisterMessage(grSim_Packet)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages_robocup_ssl_refbox_log.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import messages_robocup_ssl_detection_pb2 as messages__robocup__ssl__detection__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages_robocup_ssl_refbox_log.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%messages_robocup_ssl_refbox_log.proto\x1a$messages_robocup_ssl_detection.proto\"C\n\tLog_Frame\x12\"\n\x05\x66rame\x18\x01 \x02(\x0b\x32\x13.SSL_DetectionFrame\x12\x12\n\nrefbox_cmd\x18\x02 \x02(\t\"%\n\nRefbox_Log\x12\x17\n\x03log\x18\x01 \x03(\x0b\x32\n.Log_Frame'
  ,
  dependencies=[messages__robocup__ssl__detection__pb2.DESCRIPTOR,])




_LOG_FRAME = _descriptor.Descriptor(
  name='Log_Frame',
  full_name='Log_Frame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame', full_name='Log_Frame.frame', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refbox_cmd', full_name='Log_Frame.refbox_cmd', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=146,
)


_REFBOX_LOG = _descriptor.Descriptor(
  name='Refbox_Log',
  full_name='Refbox_Log',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Refbox_Log.log', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=185,
)

_LOG_FRAME.fields_by_name['frame'].message_type = messages__robocup__ssl__detection__pb2._SSL_DETECTIONFRAME
_REFBOX_LOG.fields_by_name['log'].message_type = _LOG_FRAME
DESCRIPTOR.message_types_by_name['Log_Frame'] = _LOG_FRAME
DESCRIPTOR.message_types_by_name['Refbox_Log'] = _REFBOX_LOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Log_Frame = _reflection.GeneratedProtocolMessageType('Log_Frame', (_message.Message,), {
  'DESCRIPTOR' : _LOG_FRAME,
  '__module__' : 'messages_robocup_ssl_refbox_log_pb2'
  # @@protoc_insertion_point(class_scope:Log_Frame)
  })
_sym_db.RegisterMessage(Log_Frame)

Refbox_Log = _reflection.GeneratedProtocolMessageType('Refbox_Log', (_message.Message,), {
  'DESCRIPTOR' : _REFBOX_LOG,
  '__module__' : 'messages_robocup_ssl_refbox_log_pb2'
  # @@protoc_insertion_point(class_scope:Refbox_Log)
  })
_sym_db.RegisterMessage(Refbox_Log)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ssl_simulation_robot_control.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ssl_simulation_robot_control.proto',
  package='',
  syntax='proto2',
  serialized_options=b'Z6github.com/RoboCup-SSL/ssl-simulation-protocol/pkg/sim',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"ssl_simulation_robot_control.proto\"\x86\x01\n\x0cRobotCommand\x12\n\n\x02id\x18\x01 \x02(\r\x12\'\n\x0cmove_command\x18\x02 \x01(\x0b\x32\x11.RobotMoveCommand\x12\x12\n\nkick_speed\x18\x03 \x01(\x02\x12\x15\n\nkick_angle\x18\x04 \x01(\x02:\x01\x30\x12\x16\n\x0e\x64ribbler_speed\x18\x05 \x01(\x02\"\xa9\x01\n\x10RobotMoveCommand\x12,\n\x0ewheel_velocity\x18\x01 \x01(\x0b\x32\x12.MoveWheelVelocityH\x00\x12,\n\x0elocal_velocity\x18\x02 \x01(\x0b\x32\x12.MoveLocalVelocityH\x00\x12.\n\x0fglobal_velocity\x18\x03 \x01(\x0b\x32\x13.MoveGlobalVelocityH\x00\x42\t\n\x07\x63ommand\"c\n\x11MoveWheelVelocity\x12\x13\n\x0b\x66ront_right\x18\x01 \x02(\x02\x12\x12\n\nback_right\x18\x02 \x02(\x02\x12\x11\n\tback_left\x18\x03 \x02(\x02\x12\x12\n\nfront_left\x18\x04 \x02(\x02\"C\n\x11MoveLocalVelocity\x12\x0f\n\x07\x66orward\x18\x01 \x02(\x02\x12\x0c\n\x04left\x18\x02 \x02(\x02\x12\x0f\n\x07\x61ngular\x18\x03 \x02(\x02\";\n\x12MoveGlobalVelocity\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\x0f\n\x07\x61ngular\x18\x03 \x02(\x02\"5\n\x0cRobotControl\x12%\n\x0erobot_commands\x18\x01 \x03(\x0b\x32\r.RobotCommandB8Z6github.com/RoboCup-SSL/ssl-simulation-protocol/pkg/sim'
)




_ROBOTCOMMAND = _descriptor.Descriptor(
  name='RobotCommand',
  full_name='RobotCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='RobotCommand.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='move_command', full_name='RobotCommand.move_command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kick_speed', full_name='RobotCommand.kick_speed', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kick_angle', full_name='RobotCommand.kick_angle', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dribbler_speed', full_name='RobotCommand.dribbler_speed', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=173,
)


_ROBOTMOVECOMMAND = _descriptor.Descriptor(
  name='RobotMoveCommand',
  full_name='RobotMoveCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wheel_velocity', full_name='RobotMoveCommand.wheel_velocity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_velocity', full_name='RobotMoveCommand.local_velocity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_velocity', full_name='RobotMoveCommand.global_velocity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='RobotMoveCommand.command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=176,
  serialized_end=345,
)


_MOVEWHEELVELOCITY = _descriptor.Descriptor(
  name='MoveWheelVelocity',
  full_name='MoveWheelVelocity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='front_right', full_name='MoveWheelVelocity.front_right', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='back_right', full_name='MoveWheelVelocity.back_right', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='back_left', full_name='MoveWheelVelocity.back_left', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_left', full_name='MoveWheelVelocity.front_left', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=446,
)


_MOVELOCALVELOCITY = _descriptor.Descriptor(
  name='MoveLocalVelocity',
  full_name='MoveLocalVelocity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='forward', full_name='MoveLocalVelocity.forward', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left', full_name='MoveLocalVelocity.left', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular', full_name='MoveLocalVelocity.angular', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=515,
)


_MOVEGLOBALVELOCITY = _descriptor.Descriptor(
  name='MoveGlobalVelocity',
  full_name='MoveGlobalVelocity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='MoveGlobalVelocity.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='MoveGlobalVelocity.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular', full_name='MoveGlobalVelocity.angular', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=576,
)


_ROBOTCONTROL = _descriptor.Descriptor(
  name='RobotControl',
  full_name='RobotControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='robot_commands', full_name='RobotControl.robot_commands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=631,
)

_ROBOTCOMMAND.fields_by_name['move_command'].message_type = _ROBOTMOVECOMMAND
_ROBOTMOVECOMMAND.fields_by_name['wheel_velocity'].message_type = _MOVEWHEELVELOCITY
_ROBOTMOVECOMMAND.fields_by_name['local_velocity'].message_type = _MOVELOCALVELOCITY
_ROBOTMOVECOMMAND.fields_by_name['global_velocity'].message_type = _MOVEGLOBALVELOCITY
_ROBOTMOVECOMMAND.oneofs_by_name['command'].fields.append(
  _ROBOTMOVECOMMAND.fields_by_name['wheel_velocity'])
_ROBOTMOVECOMMAND.fields_by_name['wheel_velocity'].containing_oneof = _ROBOTMOVECOMMAND.oneofs_by_name['command']
_ROBOTMOVECOMMAND.oneofs_by_name['command'].fields.append(
  _ROBOTMOVECOMMAND.fields_by_name['local_velocity'])
_ROBOTMOVECOMMAND.fields_by_name['local_velocity'].containing_oneof = _ROBOTMOVECOMMAND.oneofs_by_name['command']
_ROBOTMOVECOMMAND.oneofs_by_name['command'].fields.append(
  _ROBOTMOVECOMMAND.fields_by_name['global_velocity'])
_ROBOTMOVECOMMAND.fields_by_name['global_velocity'].containing_oneof = _ROBOTMOVECOMMAND.oneofs_by_name['command']
_ROBOTCONTROL.fields_by_name['robot_commands'].message_type = _ROBOTCOMMAND
DESCRIPTOR.message_types_by_name['RobotCommand'] = _ROBOTCOMMAND
DESCRIPTOR.message_types_by_name['RobotMoveCommand'] = _ROBOTMOVECOMMAND
DESCRIPTOR.message_types_by_name['MoveWheelVelocity'] = _MOVEWHEELVELOCITY
DESCRIPTOR.message_types_by_name['MoveLocalVelocity'] = _MOVELOCALVELOCITY
DESCRIPTOR.message_types_by_name['MoveGlobalVelocity'] = _MOVEGLOBALVELOCITY
DESCRIPTOR.message_types_by_name['RobotControl'] = _ROBOTCONTROL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RobotCommand = _reflection.GeneratedProtocolMessageType('RobotCommand', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTCOMMAND,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:RobotCommand)
  })
_sym_db.RegisterMessage(RobotCommand)

RobotMoveCommand = _reflection.GeneratedProtocolMessageType('RobotMoveCommand', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTMOVECOMMAND,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:RobotMoveCommand)
  })
_sym_db.RegisterMessage(RobotMoveCommand)

MoveWheelVelocity = _reflection.GeneratedProtocolMessageType('MoveWheelVelocity', (_message.Message,), {
  'DESCRIPTOR' : _MOVEWHEELVELOCITY,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:MoveWheelVelocity)
  })
_sym_db.RegisterMessage(MoveWheelVelocity)

MoveLocalVelocity = _reflection.GeneratedProtocolMessageType('MoveLocalVelocity', (_message.Message,), {
  'DESCRIPTOR' : _MOVELOCALVELOCITY,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:MoveLocalVelocity)
  })
_sym_db.RegisterMessage(MoveLocalVelocity)

MoveGlobalVelocity = _reflection.GeneratedProtocolMessageType('MoveGlobalVelocity', (_message.Message,), {
  'DESCRIPTOR' : _MOVEGLOBALVELOCITY,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:MoveGlobalVelocity)
  })
_sym_db.RegisterMessage(MoveGlobalVelocity)

RobotControl = _reflection.GeneratedProtocolMessageType('RobotControl', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTCONTROL,
  '__module__' : 'ssl_simulation_robot_control_pb2'
  # @@protoc_insertion_point(class_scope:RobotControl)
  })
_sym_db.RegisterMessage(RobotControl)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages_robocup_ssl_geometry_legacy.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import messages_robocup_ssl_geometry_pb2 as messages__robocup__ssl__geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages_robocup_ssl_geometry_legacy.proto',
  package='RoboCup2014Legacy.Geometry',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*messages_robocup_ssl_geometry_legacy.proto\x12\x1aRoboCup2014Legacy.Geometry\x1a#messages_robocup_ssl_geometry.proto\"\x8a\x03\n\x15SSL_GeometryFieldSize\x12\x12\n\nline_width\x18\x01 \x02(\x05\x12\x14\n\x0c\x66ield_length\x18\x02 \x02(\x05\x12\x13\n\x0b\x66ield_width\x18\x03 \x02(\x05\x12\x16\n\x0e\x62oundary_width\x18\x04 \x02(\x05\x12\x15\n\rreferee_width\x18\x05 \x02(\x05\x12\x12\n\ngoal_width\x18\x06 \x02(\x05\x12\x12\n\ngoal_depth\x18\x07 \x02(\x05\x12\x17\n\x0fgoal_wall_width\x18\x08 \x02(\x05\x12\x1c\n\x14\x63\x65nter_circle_radius\x18\t \x02(\x05\x12\x16\n\x0e\x64\x65\x66\x65nse_radius\x18\n \x02(\x05\x12\x17\n\x0f\x64\x65\x66\x65nse_stretch\x18\x0b \x02(\x05\x12#\n\x1b\x66ree_kick_from_defense_dist\x18\x0c \x02(\x05\x12)\n!penalty_spot_from_field_line_dist\x18\r \x02(\x05\x12#\n\x1bpenalty_line_from_spot_dist\x18\x0e \x02(\x05\"\x83\x01\n\x10SSL_GeometryData\x12@\n\x05\x66ield\x18\x01 \x02(\x0b\x32\x31.RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize\x12-\n\x05\x63\x61lib\x18\x02 \x03(\x0b\x32\x1e.SSL_GeometryCameraCalibration'
  ,
  dependencies=[messages__robocup__ssl__geometry__pb2.DESCRIPTOR,])




_SSL_GEOMETRYFIELDSIZE = _descriptor.Descriptor(
  name='SSL_GeometryFieldSize',
  full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_width', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.line_width', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_length', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.field_length', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_width', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.field_width', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary_width', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.boundary_width', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referee_width', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.referee_width', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_width', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.goal_width', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_depth', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.goal_depth', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_wall_width', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.goal_wall_width', index=7,
      number=8, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center_circle_radius', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.center_circle_radius', index=8,
      number=9, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defense_radius', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.defense_radius', index=9,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defense_stretch', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.defense_stretch', index=10,
      number=11, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='free_kick_from_defense_dist', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.free_kick_from_defense_dist', index=11,
      number=12, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty_spot_from_field_line_dist', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.penalty_spot_from_field_line_dist', index=12,
      number=13, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty_line_from_spot_dist', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize.penalty_line_from_spot_dist', index=13,
      number=14, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=506,
)


_SSL_GEOMETRYDATA = _descriptor.Descriptor(
  name='SSL_GeometryData',
  full_name='RoboCup2014Legacy.Geometry.SSL_GeometryData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryData.field', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calib', full_name='RoboCup2014Legacy.Geometry.SSL_GeometryData.calib', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=640,
)

_SSL_GEOMETRYDATA.fields_by_name['field'].message_type = _SSL_GEOMETRYFIELDSIZE
_SSL_GEOMETRYDATA.fields_by_name['calib'].message_type = messages__robocup__ssl__geometry__pb2._SSL_GEOMETRYCAMERACALIBRATION
DESCRIPTOR.message_types_by_name['SSL_GeometryFieldSize'] = _SSL_GEOMETRYFIELDSIZE
DESCRIPTOR.message_types_by_name['SSL_GeometryData'] = _SSL_GEOMETRYDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SSL_GeometryFieldSize = _reflection.GeneratedProtocolMessageType('SSL_GeometryFieldSize', (_message.Message,), {
  'DESCRIPTOR' : _SSL_GEOMETRYFIELDSIZE,
  '__module__' : 'messages_robocup_ssl_geometry_legacy_pb2'
  # @@protoc_insertion_point(class_scope:RoboCup2014Legacy.Geometry.SSL_GeometryFieldSize)
  })
_sym_db.RegisterMessage(SSL_GeometryFieldSize)

SSL_GeometryData = _reflection.GeneratedProtocolMessageType('SSL_GeometryData', (_message.Message,), {
  'DESCRIPTOR' : _SSL_GEOMETRYDATA,
  '__module__' : 'messages_robocup_ssl_geometry_legacy_pb2'
  # @@protoc_insertion_point(class_scope:RoboCup2014Legacy.Geometry.SSL_GeometryData)
  })
_sym_db.RegisterMessage(SSL_GeometryData)


# @@protoc_insertion_point(module_scope)



import importlib.resources
import logging
import os
from logging.handlers import TimedRotatingFileHandler
from pathlib import Path


def get_project_root() -> Path:
    with importlib.resources.path("strategy_bridge", "__init__.py") as src_path:
        path = src_path.parents[2]
    return path


PROJECT_ROOT = get_project_root()

VISION_DETECTIONS_SUBSCRIBE_PORT = 4242
REFEREE_COMMANDS_SUBSCRIBE_PORT = 4243
COMMANDS_PUBLISH_PORT = 5667

VISION_DETECTIONS_TOPIC = "vision-detections"
REFEREE_COMMANDS_TOPIC = "referee-commands"
ROBOT_COMMANDS_TOPIC = "robot-commands"

LOG_FILE_NAME = "strategy-bridge.log"
CONFIG_FILE_NAME = "bridge.yml"

LOG_PATH = os.path.join(PROJECT_ROOT, "logs")
CONFIG_PATH = os.path.join(PROJECT_ROOT, "conf")
MATLAB_SCRIPTS_PATH = os.path.join(PROJECT_ROOT, "..", "MLscripts_func_main")


def init_logging(log_dir=LOG_PATH, log_file_name=LOG_FILE_NAME):
    logging_format = "[%(asctime)s] [%(levelname)s] [%(name)s] %(message)s"
    formatter = logging.Formatter(logging_format)

    file_handler = TimedRotatingFileHandler(filename=os.path.join(log_dir, log_file_name), when='W0')
    file_handler.setLevel(logging.INFO)
    file_handler.setFormatter(formatter)

    console_handler = logging.StreamHandler()
    console_handler.setLevel(logging.INFO)
    console_handler.setFormatter(formatter)

    logging.getLogger().addHandler(console_handler)
    logging.getLogger().addHandler(file_handler)
    logging.getLogger().setLevel(logging.INFO)



import attr
import typing

from collections import deque

from strategy_bridge.bus.record import Record


@attr.s(auto_attribs=True)
class DataBus:
    def __attrs_post_init__(self):
        self.data: typing.Dict[str, deque[Record]] = {}

    def register_topic(self, topic_name: str, max_size: int) -> None:
        self.data[topic_name] = deque(maxlen=max_size)

    def write(self, topic_name: str, record: Record) -> None:
        self.data[topic_name].append(record)

    def read_all(self, topic_name) -> typing.List[Record]:
        data = self.data.get(topic_name)
        if not data:
            print(f"No data in topic {topic_name}")
            return []
        return list(data)

    def read_top(self, topic_name: str, count: int) -> typing.List[Record]:
        return self.read_all(topic_name)[-count:]

    def read_from_timestamp(self, topic_name: str, timestamp: float) -> typing.List[Record]:
        records = self.read_all(topic_name)
        valid_records = [r for r in records if r.timestamp > timestamp]
        return valid_records


data_bus = DataBus()



import typing

import attr
import zmq


@attr.s(auto_attribs=True, kw_only=True)
class ZmqReceiver:

    port: int

    def __attrs_post_init__(self) -> None:
        context = zmq.Context()
        self.socket = context.socket(zmq.SUB)

        self.socket.connect(f"tcp://localhost:{self.port}")
        self.socket.subscribe("")

    def next_message(self) -> typing.Optional[typing.ByteString]:
        try:
            return self.socket.recv(flags=zmq.NOBLOCK)
        except zmq.ZMQError:
            return None



from strategy_bridge.common import config
from strategy_bridge.processors import VisionDetectionsCollector, RobotCommandsSender
from strategy_bridge.processors.python_controller_template import PythonControllerTemplate
from strategy_bridge.processors.referee_commands_collector import RefereeCommandsCollector
from strategy_bridge.runner import Runner


if __name__ == '__main__':

    config.init_logging()

    # TODO: Move list of processors to config
    processors = [
        VisionDetectionsCollector(),
        RefereeCommandsCollector(),
        PythonControllerTemplate(),
        RobotCommandsSender()
    ]

    runner = Runner(processors=processors)
    runner.run()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grsim_replacement.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grsim_replacement.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17grsim_replacement.proto\"[\n\x16grSim_RobotReplacement\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\x0b\n\x03\x64ir\x18\x03 \x02(\x01\x12\n\n\x02id\x18\x04 \x02(\r\x12\x12\n\nyellowteam\x18\x05 \x02(\x08\"E\n\x15grSim_BallReplacement\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\n\n\x02vx\x18\x03 \x02(\x01\x12\n\n\x02vy\x18\x04 \x02(\x01\"b\n\x11grSim_Replacement\x12$\n\x04\x62\x61ll\x18\x01 \x01(\x0b\x32\x16.grSim_BallReplacement\x12\'\n\x06robots\x18\x02 \x03(\x0b\x32\x17.grSim_RobotReplacement'
)




_GRSIM_ROBOTREPLACEMENT = _descriptor.Descriptor(
  name='grSim_RobotReplacement',
  full_name='grSim_RobotReplacement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='grSim_RobotReplacement.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='grSim_RobotReplacement.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dir', full_name='grSim_RobotReplacement.dir', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='grSim_RobotReplacement.id', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yellowteam', full_name='grSim_RobotReplacement.yellowteam', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=118,
)


_GRSIM_BALLREPLACEMENT = _descriptor.Descriptor(
  name='grSim_BallReplacement',
  full_name='grSim_BallReplacement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='grSim_BallReplacement.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='grSim_BallReplacement.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vx', full_name='grSim_BallReplacement.vx', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vy', full_name='grSim_BallReplacement.vy', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=189,
)


_GRSIM_REPLACEMENT = _descriptor.Descriptor(
  name='grSim_Replacement',
  full_name='grSim_Replacement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ball', full_name='grSim_Replacement.ball', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robots', full_name='grSim_Replacement.robots', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=289,
)

_GRSIM_REPLACEMENT.fields_by_name['ball'].message_type = _GRSIM_BALLREPLACEMENT
_GRSIM_REPLACEMENT.fields_by_name['robots'].message_type = _GRSIM_ROBOTREPLACEMENT
DESCRIPTOR.message_types_by_name['grSim_RobotReplacement'] = _GRSIM_ROBOTREPLACEMENT
DESCRIPTOR.message_types_by_name['grSim_BallReplacement'] = _GRSIM_BALLREPLACEMENT
DESCRIPTOR.message_types_by_name['grSim_Replacement'] = _GRSIM_REPLACEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

grSim_RobotReplacement = _reflection.GeneratedProtocolMessageType('grSim_RobotReplacement', (_message.Message,), {
  'DESCRIPTOR' : _GRSIM_ROBOTREPLACEMENT,
  '__module__' : 'grsim_replacement_pb2'
  # @@protoc_insertion_point(class_scope:grSim_RobotReplacement)
  })
_sym_db.RegisterMessage(grSim_RobotReplacement)

grSim_BallReplacement = _reflection.GeneratedProtocolMessageType('grSim_BallReplacement', (_message.Message,), {
  'DESCRIPTOR' : _GRSIM_BALLREPLACEMENT,
  '__module__' : 'grsim_replacement_pb2'
  # @@protoc_insertion_point(class_scope:grSim_BallReplacement)
  })
_sym_db.RegisterMessage(grSim_BallReplacement)

grSim_Replacement = _reflection.GeneratedProtocolMessageType('grSim_Replacement', (_message.Message,), {
  'DESCRIPTOR' : _GRSIM_REPLACEMENT,
  '__module__' : 'grsim_replacement_pb2'
  # @@protoc_insertion_point(class_scope:grSim_Replacement)
  })
_sym_db.RegisterMessage(grSim_Replacement)


# @@protoc_insertion_point(module_scope)



import typing

import attr

from strategy_bridge.bus import data_bus, Record


@attr.s(auto_attribs=True)
class DataReader:

    read_topic_name: str
    last_read_message_timestamp: float = 0

    def read_new(self) -> typing.List[typing.Any]:
        records = data_bus.read_from_timestamp(self.read_topic_name, self.last_read_message_timestamp)
        if records:
            self.last_read_message_timestamp = records[-1].timestamp
        return [r.content for r in records]

    def read_all(self) -> typing.List[Record]:
        return data_bus.read_all(self.read_topic_name)



import attr
import zmq

from strategy_bridge.bus import DataReader
from strategy_bridge.common import config
from strategy_bridge.processors import BaseProcessor


@attr.s(auto_attribs=True)
class RobotCommandsSender(BaseProcessor):

    commands_reader: DataReader = attr.ib(init=False, default=DataReader(config.ROBOT_COMMANDS_TOPIC))

    def __attrs_post_init__(self) -> None:
        context = zmq.Context()
        self.socket = context.socket(zmq.PUB)
        self.socket.bind(f"tcp://*:{config.COMMANDS_PUBLISH_PORT}")

    async def process(self):
        commands = self.commands_reader.read_new()
        for command in commands:
            self.socket.send(command)



import asyncio
import threading
import typing

import attr

from strategy_bridge.processors import BaseProcessor


@attr.s(auto_attribs=True, kw_only=True)
class Runner:
    processors: typing.List[BaseProcessor]

    def run(self):
        loop = asyncio.get_event_loop()
        t = threading.Thread(target=self.loop_in_thread, args=(loop,))
        t.start()

    async def run_tasks(self):
        tasks = [asyncio.create_task(processor.run()) for processor in self.processors]
        await asyncio.gather(*tasks)

    def loop_in_thread(self, loop):
        asyncio.set_event_loop(loop)
        loop.run_until_complete(self.run_tasks())


# loop = asyncio.get_event_loop()
# loop.create_task(matlab_controller.run())
# loop.create_task(collector.run())
# loop.run_forever()
#
# def loop_in_thread1(loop):
#     asyncio.set_event_loop(loop)
#     # loop.run_until_complete(run_all())
#     loop.run_until_complete(matlab_controller.run())
#
# loop2 = asyncio.get_event_loop()
# t2 = threading.Thread(target=loop_in_thread1, args=(loop1,))
# t2.start()
